==> activity-center-biz-1.0.2-20160701.054452-45-sources.jar: cn/com/duiba/activity/center/biz/remoteservice/impl/game/RemoteDuibaQuestionAnswerServiceNewImpl.java <==
package cn.com.duiba.activity.center.biz.remoteservice.impl.game;

import cn.com.duiba.activity.center.api.dto.ActivityExtraInfoDto;
import cn.com.duiba.activity.center.api.dto.game.DuibaQuestionAnswerDto;
import cn.com.duiba.activity.center.api.dto.quizz.AddActivityDto;
import cn.com.duiba.activity.center.api.remoteservice.game.RemoteDuibaQuestionAnswerServiceNew;
import cn.com.duiba.activity.center.biz.service.game.DuibaQuestionAnswerService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * Created by wenqi.huang on 16/5/19.
 */
@Service
public class RemoteDuibaQuestionAnswerServiceNewImpl implements RemoteDuibaQuestionAnswerServiceNew {
    @Resource
    private DuibaQuestionAnswerService duibaQuestionAnswerService;

    @Override
    public DuibaQuestionAnswerDto find(Long id) {
        return duibaQuestionAnswerService.find(id);
    }

    @Override
    public List<DuibaQuestionAnswerDto> findAutoOff() {
        return duibaQuestionAnswerService.findAutoOff();
    }

    @Override
    public int updateStatus(Long id, Integer status) {
        return duibaQuestionAnswerService.updateStatus(id, status);
    }

    @Override
    public List<DuibaQuestionAnswerDto> findByIds(List<Long> ids) {
        return duibaQuestionAnswerService.findByIds(ids);
    }

    @Override
    public ActivityExtraInfoDto findExtraInfoById(Long id) {
        return duibaQuestionAnswerService.findExtraInfoById(id);
    }

    @Override
    public List<DuibaQuestionAnswerDto> findAllByIds(List<Long> ids) {
        return duibaQuestionAnswerService.findAllByIds(ids);
    }

    @Override
    public List<AddActivityDto> findAllQuestion(Long appId) {
        return duibaQuestionAnswerService.findAllQuestion(appId);
    }

    @Override
    public List<DuibaQuestionAnswerDto> findByPage(Integer offset, Integer max) {
        return duibaQuestionAnswerService.findByPage(offset, max);
    }

    @Override
    public Long findPageCount() {
        return duibaQuestionAnswerService.findPageCount();
    }

    @Override
    public Long findPageCount(Map<String, Object> paramMap) {
        return duibaQuestionAnswerService.findPageCount(paramMap);
    }

    @Override
    public List<DuibaQuestionAnswerDto> findByPage(Map<String, Object> paramMap) {
        return duibaQuestionAnswerService.findByPage(paramMap);
    }

    @Override
    public int updateStatus(Long id, int status) {
        return duibaQuestionAnswerService.updateStatus(id, status);
    }

    @Override
    public int delete(Long id) {
        return duibaQuestionAnswerService.delete(id);
    }

    @Override
    public DuibaQuestionAnswerDto insert(DuibaQuestionAnswerDto duibaQuestionAnswerDto) {
        duibaQuestionAnswerService.insert(duibaQuestionAnswerDto);
        return duibaQuestionAnswerDto;
    }

    @Override
    public int update(DuibaQuestionAnswerDto duibaQuestionAnswerDto) {
        return duibaQuestionAnswerService.update(duibaQuestionAnswerDto);
    }

    @Override
    public int updateAutoOffDateNull(Long id) {
        return duibaQuestionAnswerService.updateAutoOffDateNull(id);
    }

    @Override
    public void updateSwitches(Long id, Long switches) {
        duibaQuestionAnswerService.updateSwitches(id, switches);
    }

}

==> activity-center-biz-1.0.2-20160706.034119-56-sources.jar: cn/com/duiba/activity/center/biz/remoteservice/impl/game/RemoteDuibaQuestionAnswerServiceNewImpl.java <==
package cn.com.duiba.activity.center.biz.remoteservice.impl.game;

import cn.com.duiba.activity.center.api.dto.ActivityExtraInfoDto;
import cn.com.duiba.activity.center.api.dto.game.DuibaQuestionAnswerDto;
import cn.com.duiba.activity.center.api.dto.quizz.AddActivityDto;
import cn.com.duiba.activity.center.api.remoteservice.game.RemoteDuibaQuestionAnswerServiceNew;
import cn.com.duiba.activity.center.biz.service.game.DuibaQuestionAnswerService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * Created by wenqi.huang on 16/5/19.
 */
@Service
public class RemoteDuibaQuestionAnswerServiceNewImpl implements RemoteDuibaQuestionAnswerServiceNew {
    @Resource
    private DuibaQuestionAnswerService duibaQuestionAnswerService;

    @Override
    public DuibaQuestionAnswerDto find(Long id) {
        return duibaQuestionAnswerService.find(id);
    }

    @Override
    public List<DuibaQuestionAnswerDto> findAutoOff() {
        return duibaQuestionAnswerService.findAutoOff();
    }

    @Override
    public int updateStatus(Long id, Integer status) {
        return duibaQuestionAnswerService.updateStatus(id, status);
    }

    @Override
    public List<DuibaQuestionAnswerDto> findByIds(List<Long> ids) {
        return duibaQuestionAnswerService.findByIds(ids);
    }

    @Override
    public ActivityExtraInfoDto findExtraInfoById(Long id) {
        return duibaQuestionAnswerService.findExtraInfoById(id);
    }

    @Override
    public List<DuibaQuestionAnswerDto> findAllByIds(List<Long> ids) {
        return duibaQuestionAnswerService.findAllByIds(ids);
    }

    @Override
    public List<AddActivityDto> findAllQuestion(Long appId) {
        return duibaQuestionAnswerService.findAllQuestion(appId);
    }

    @Override
    public List<DuibaQuestionAnswerDto> findByPage(Integer offset, Integer max) {
        return duibaQuestionAnswerService.findByPage(offset, max);
    }

    @Override
    public Long findPageCount() {
        return duibaQuestionAnswerService.findPageCount();
    }

    @Override
    public Long findPageCount(Map<String, Object> paramMap) {
        return duibaQuestionAnswerService.findPageCount(paramMap);
    }

    @Override
    public List<DuibaQuestionAnswerDto> findByPage(Map<String, Object> paramMap) {
        return duibaQuestionAnswerService.findByPage(paramMap);
    }

    @Override
    public int updateStatus(Long id, int status) {
        return duibaQuestionAnswerService.updateStatus(id, status);
    }

    @Override
    public int delete(Long id) {
        return duibaQuestionAnswerService.delete(id);
    }

    @Override
    public DuibaQuestionAnswerDto insert(DuibaQuestionAnswerDto duibaQuestionAnswerDto) {
        duibaQuestionAnswerService.insert(duibaQuestionAnswerDto);
        return duibaQuestionAnswerDto;
    }

    @Override
    public int update(DuibaQuestionAnswerDto duibaQuestionAnswerDto) {
        return duibaQuestionAnswerService.update(duibaQuestionAnswerDto);
    }

    @Override
    public int updateAutoOffDateNull(Long id) {
        return duibaQuestionAnswerService.updateAutoOffDateNull(id);
    }

    @Override
    public void updateSwitches(Long id, Long switches) {
        duibaQuestionAnswerService.updateSwitches(id, switches);
    }

    @Override
    public int updateForEditActivityCategoryId(long id, Long activityCategoryId) {
        return duibaQuestionAnswerService.updateForEditActivityCategoryId(id, activityCategoryId);
    }
}
